================
For Russian only 
================

Vacancy is open: http://hh.ru/vacancy/13540190


=====
About
=====

This is framework for test development with complex logic around, well, based on nose library.
You will can to build your regression testing on base noseapp library and will create your own extensions.

We are offer see our development:

* noseapp_selenium - https://pypi.python.org/pypi/noseapp_selenium
* noseapp_daemon https://pypi.python.org/pypi/noseapp_daemon
* noseapp_requests https://pypi.python.org/pypi/noseapp_requests
* noseapp_alchemy - https://pypi.python.org/pypi/noseapp_alchemy


To see docs: http://pythonhosted.org/noseapp/


============
Installation
============

::

  pip install noseapp
